From cca031b1b9a4554baab49ea5a1e8612bbd6ddcfc Mon Sep 17 00:00:00 2001
From: rayg <rayg@ssec.wisc.edu>
Date: Thu, 5 Dec 2019 17:16:47 +0000
Subject: [PATCH] Add mk_cris and sunset mk_astro; cris = cspp - pycdf +
 astropy currently. Also revbump astropy to 3.2.3 and astropy-helpers to 3.2.2

---
 ShellB3/shallbethree.sh                       | 39 +++++++++++--------
 ShellB3/src/optional/astropy-3.2.2.tar.gz     |  3 --
 ShellB3/src/optional/astropy-3.2.3.tar.gz     |  3 ++
 .../src/optional/astropy-helpers-3.2.1.tar.gz |  3 --
 .../src/optional/astropy-helpers-3.2.2.tar.gz |  3 ++
 5 files changed, 29 insertions(+), 22 deletions(-)
 delete mode 100644 ShellB3/src/optional/astropy-3.2.2.tar.gz
 create mode 100644 ShellB3/src/optional/astropy-3.2.3.tar.gz
 delete mode 100644 ShellB3/src/optional/astropy-helpers-3.2.1.tar.gz
 create mode 100644 ShellB3/src/optional/astropy-helpers-3.2.2.tar.gz

diff --git a/ShellB3/src/optional/astropy-3.2.2.tar.gz b/ShellB3/src/optional/astropy-3.2.2.tar.gz
deleted file mode 100644
index 796c5eb9..00000000
--- a/ShellB3/src/optional/astropy-3.2.2.tar.gz
+++ /dev/null
@@ -1,3 +0,0 @@
-version https://git-lfs.github.com/spec/v1
-oid sha256:8553f4a95e9938a0c7ae520633f7172356824b8eb324dd967fca6baf00ac19bf
-size 7965010
diff --git a/ShellB3/src/optional/astropy-3.2.3.tar.gz b/ShellB3/src/optional/astropy-3.2.3.tar.gz
new file mode 100644
index 00000000..cd0d74f5
--- /dev/null
+++ b/ShellB3/src/optional/astropy-3.2.3.tar.gz
@@ -0,0 +1,3 @@
+version https://git-lfs.github.com/spec/v1
+oid sha256:47f00816c2978fdd10f448c8f0337d6dca7b8cbeaab4bf272b5fd37cb4b890d3
+size 7964789
diff --git a/ShellB3/src/optional/astropy-helpers-3.2.1.tar.gz b/ShellB3/src/optional/astropy-helpers-3.2.1.tar.gz
deleted file mode 100644
index 7f4f9698..00000000
--- a/ShellB3/src/optional/astropy-helpers-3.2.1.tar.gz
+++ /dev/null
@@ -1,3 +0,0 @@
-version https://git-lfs.github.com/spec/v1
-oid sha256:46edef2a3cc48cffe29e127eab173cadde52375875fc60cff070c144b7f39dce
-size 52857
diff --git a/ShellB3/src/optional/astropy-helpers-3.2.2.tar.gz b/ShellB3/src/optional/astropy-helpers-3.2.2.tar.gz
new file mode 100644
index 00000000..ac244da5
--- /dev/null
+++ b/ShellB3/src/optional/astropy-helpers-3.2.2.tar.gz
@@ -0,0 +1,3 @@
+version https://git-lfs.github.com/spec/v1
+oid sha256:cf32cb008b19597a1fe1a4d97f59734f30cd513aa3369a321e7b5b86cdb623fb
+size 52558
diff --git a/ShellB3/shallbethree.sh b/ShellB3/shallbethree.sh
index 7e439550..822b0529 100755
--- a/ShellB3/shallbethree.sh
+++ b/ShellB3/shallbethree.sh
@@ -954,8 +954,8 @@ export PANDASVER=0.25.3
 
 export ASTROPY2HELPERSVER=2.0.6
 export ASTROPY2VER=2.0.5
-export ASTROPYHELPERSVER=3.2.1
-export ASTROPYVER=3.2.2
+export ASTROPYHELPERSVER=3.2.2
+export ASTROPYVER=3.2.3
 export BLISTVER=1.3.6
 export BITARRAYVER=1.0.1
 export UPDATESVER=0.1.7.1
@@ -6635,11 +6635,10 @@ mk_geos() {
 mk_astropy() {
   #build astropy and some dependencies (not a full trim)
   resume_tracker && return 0
-  pip_install src/optional/futures*z || oops 'futures did not install'
   pip_install src/optional/MarkupSafe*z || oops 'MarkupSafe did not install'
   pip_install src/optional/Jinja2*z || oops "Jinja2 did not install"
   pip_install src/optional/py-*z || oops 'py did not install'
-  mk_pytest || oops 'pytest did not install'
+  # mk_pytest || oops 'pytest did not install'
   if isPython2 ; then
     _setup_build_install astropy-helpers src/optional/astropy-helpers-${ASTROPY2HELPERSVER}.tar.gz astropy-helpers-${ASTROPY2HELPERSVER}
     _setup_build_install astropy src/optional/astropy-${ASTROPY2VER}.tar.gz astropy-${ASTROPY2VER} 
@@ -10458,29 +10457,36 @@ mk_core() {
     echo core >>trim
 }
 
-# new 20151111
-mk_astro() {
-  # astro trim
+mk_cspp() {
+  # used by CSPP, includes batch graphics support for quicklooks. Builds Python3
   resume_tracker && return 0
+  TRIM_PYTHON_VERSION=3
     mk_core \
+    && mk_graphics \
     && mk_hdf4 && mk_pyhdf \
     && mk_netcdf4 && mk_pycdf && mk_netcdf4py \
+    && mk_pylibtiff \
     && mk_pycparser \
     && mk_cffi \
-    && mk_astropy \
-    && mk_bitarray \
-    && mk_blist
-    echo astro >>trim
+    && mk_shapely \
+    && mk_inotify \
+    && mk_configobj \
+    && mk_pyyaml \
+    && mk_pykdtree \
+    && mk_pyresample \
+    && mk_bottleneck \
+    && mk_gdal
+    echo cspp >>trim
 }
 
-mk_cspp() {
-  # used by CSPP, includes batch graphics support for quicklooks. Builds Python3
+mk_cris() {
+  # used by CrIS L1b v3, includes batch graphics support for quicklooks. Builds Python3
   resume_tracker && return 0
   TRIM_PYTHON_VERSION=3
     mk_core \
     && mk_graphics \
     && mk_hdf4 && mk_pyhdf \
-    && mk_netcdf4 && mk_pycdf && mk_netcdf4py \
+    && mk_netcdf4 && mk_netcdf4py \
     && mk_pylibtiff \
     && mk_pycparser \
     && mk_cffi \
@@ -10491,8 +10497,9 @@ mk_cspp() {
     && mk_pykdtree \
     && mk_pyresample \
     && mk_bottleneck \
-    && mk_gdal
-    echo cspp >>trim
+    && mk_gdal \
+    && mk_astropy
+    echo cris >>trim
 }
 
 mk_scmi() {
-- 
GitLab